pyNSID
======

.. image:: https://github.com/pycroscopy/pyNSID/workflows/build/badge.svg?branch=master
    :target: https://github.com/pycroscopy/pyNSID/actions?query=workflow%3Abuild
    :alt: GitHub Actions

.. image:: https://img.shields.io/pypi/v/pynsid.svg
    :target: https://pypi.org/project/pynsid/
    :alt: PyPI

.. image:: https://codecov.io/gh/pycroscopy/pyNSID/branch/master/graph/badge.svg?token=484EH7UML3
    :target: https://codecov.io/gh/pycroscopy/pyNSID
    :alt: CodeCov

.. image:: https://img.shields.io/pypi/l/pynsid.svg
    :target: https://pypi.org/project/pynsid/
    :alt: License

.. image:: http://pepy.tech/badge/pynsid
    :target: http://pepy.tech/project/pynsid
    :alt: Downloads


Framework for storing, visualizing, and processing N-Dimensional Spectroscopic and Imaging Data (NSID)

Please see our `website <https://pycroscopy.github.io/pyNSID/about.html>`_ for more information.

**This package is under development**
